package ru.myitschool.work.api

import okhttp3.ResponseBody
import retrofit2.Response
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.Header
import retrofit2.http.PATCH
import retrofit2.http.POST
import retrofit2.http.Path
import retrofit2.http.Query

interface ApiService {
    // Метод для аутентификации
    @GET("/api/auth")
    suspend fun authenticate(
        @Query("login") login: String,
        @Query("password") password: String
    ): Response<Unit> // Измените Response<String> на Response<Unit>

    @GET("/api/{login}/info")
    suspend fun getUserInfo(
    @Path("login") login: String,
    @Header("Authorization") authHeader: String
    ): Response<EmployeeData>

    @GET("/api/employee/{login}") // Получение информации о сотруднике
    suspend fun getEmployeeInfo(@Path("login") login: String): Response<EmployeeData>

    @PATCH("/api/open") // Открыть дверь
    suspend fun openDoor(
        @Header("Authorization") authHeader: String,
        @Body request: OpenDoorRequest
    ): Response<Unit> // Измените Response<String> на Response<Unit>

    @POST("/api/employee/toggleAccess") // Метод для блокировки/разблокировки доступа
    suspend fun toggleAccess(@Body request: ToggleAccessRequest): Response<Unit>

    @GET("/api/workers") // Получить всех сотрудников
    suspend fun getAllWorkers(): Response<List<EmployeeData>>
}

// Модель данных для информации о сотруднике
data class EmployeeData(
    val name: String,
    val position: String,
    val lastVisit: String
)

// Модель данных для запроса блокировки/разблокировки доступа
data class ToggleAccessRequest(
    val login: String, // Логин сотрудника
    val action: String // Действие: "block" или "unblock"
)

// Модель данных для запроса открытия двери
data class OpenDoorRequest(
    val login: String, // Логин сотрудника
    val value: Long // Код для открытия двери
)